from setuptools import setup

setup(
   name='rokkket',
   version='1.0.0',
   author='DJEBARRA Rabah Abderrazak',
   author_email='djebarra.ra@gmail.com',
   packages=['rokkket'],
   url='http://pypi.python.org/pypi/rocket',
   license='LICENSE.txt',
   description='An awesome package that only allows you to create rockets',
   long_description=open('README.md').read(),
   long_description_content_type="text/markdown",
   
)